/**
 * Copyright (c) 2022 - present TinyVue Authors.
 * Copyright (c) 2022 - present Huawei Cloud Computing Technologies Co., Ltd.
 *
 * Use of this source code is governed by an MIT-style license.
 *
 * THE OPEN SOURCE SOFTWARE IN THIS PRODUCT IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL,
 * BUT WITHOUT ANY WARRANTY, WITHOUT EVEN THE IMPLIED WARRANTY OF MERCHANTABILITY OR FITNESS FOR
 * A PARTICULAR PURPOSE. SEE THE APPLICABLE LICENSES FOR MORE DETAILS.
 *
 */
/**
 * 返回在数组中可以找到一个给定元素的第一个索引，如果不存在，则返回-1。 TINY_NO_NEED 现在数组有 findIndex
 * 修复数组原生的 indexOf 方法不能判断 NaN 的问题
 *
 *     let arr1 = [1, 2, 3, 4]
 *     let arr2 = [1, 2, NaN, 4]
 *     indexOf(arr1, 2)   // 1
 *     indexOf(arr2, NaN) // 2
 *
 * @param {Array<T>} arr 要查找的数组
 * @param {T} data  需要查找的数据
 * @param {Function} [predicate] 断言函数，缺省为 isSame, 两个参数为数组的元素和查找的数据
 * @returns {number} 元素在数组中的索引，如果不存在则返回-1
 */
export declare const indexOf: <T>(arr: T[], data: T, predicate?: (item: T, target: T) => boolean) => number;
/**
 * 在数组里查找对象，调用自定义的断言函数。
 *
 *     let arr = [1, 2, 3, 4]
 *     find(arr, function (value) { return value > 2 })   // 3
 *
 * @param {Array<T>} arr 要查找的数组
 * @param {Function} predicate 断言函数
 * @returns {T | undefined} 找到的元素，如果没有找到则返回undefined
 */
export declare const find: <T>(arr: T[], predicate: (item: T, index: number) => boolean) => T | undefined;
/**
 * 从数组中删除指定元素，并返回该数组。
 *
 *     let arr1 = [1, 2, 3, 4]
 *     let arr2 = [1, 2, NaN, 4]
 *     remove(arr1, 2, 2) // [1, 4]
 *     remove(arr2, NaN)  // [1, 2, 4]
 *
 * @param {Array<T>} arr 源数组
 * @param {T} data  需要删除的数据
 * @param {number} count 删除元素个数，默认为 1
 * @returns {Array<T>} 处理后的数组
 */
export declare const remove: <T>(arr: T[], data: T, count?: number) => T[];
/**
 * 对象数组自定义排序，并返回该数组。
 *
 *     sort([ {a:100}, {a:1}, {a:NaN}, {a:10} ], 'a')        // [ {a:1}, {a:10}, {a:100}, {a:NaN} ]
 *     sort([ {a:100}, {a:1}, {a:NaN}, {a:10} ], 'a','desc') // [ {a:100}, {a:10}, {a:1}, {a:NaN} ]
 *
 * @param {Array<T>} arr 需要排序的对象数组
 * @param {string} field 要排序的对象字段
 * @param {string} sort 排序方向，取值为 "asc" 或 "desc"
 * @returns {Array<T>} 排好序的对象数组
 */
export declare const sort: <T extends Record<string, any>>(arr: T[], field: string, sort?: string) => T[];
/**
 * 向数组中添加不重复的数据，并返回该数组。
 *
 *     let arr = [ 1, 2, NaN, 4]
 *     push(arr, 1)   // [ 1, 2, NaN, 4]
 *     push(arr, NaN) // [ 1, 2, NaN, 4]
 *     push(arr, 5)   // [ 1, 2, NaN, 4, 5]
 *
 * @param {Array<T>} arr 源数组
 * @param {T} data 需要增加的数据
 * @returns {Array<T>} 处理后的数组
 */
export declare const push: <T>(arr: T[], data: T) => T[];
/**
 * 去除数组中的重复的值，并返回新数组。
 *
 *     let arr = [ 1, NaN, 2, NaN, 2, 3, 4]
 *     unique(arr) // [ 1, NaN, 2, 3, 4]
 *
 * @param {Array<T>} arr 源数组
 * @returns {Array<T>} 去重后的新数组
 */
export declare const unique: <T>(arr: T[]) => T[];
/**
 * 数组转对象
 *
 *     let arr = [ { key1: value1 }, { key2: value2 } ]
 *     toObject(arr) // { key1: value1, key2: value2 }
 *
 * @param {Array<Record<string, any>>} arr 包含对象的数组
 * @returns {Record<string, any>} 合并后的对象
 */
export declare const toObject: (arr: Record<string, any>[]) => Record<string, any>;
/**
 * 将 id 与 pid 构成的扁平数据转换成 children 的树状数据
 *
 *     let data = [{ id: 100, pId: 0, label: '首页'}, { id: 101, pId: 100, label: '指南'}]
 *     transformPidToChildren(data) // [ 0: { id: 100, label: "首页", children: [ 0: { id: 101, label: "指南" } ] } ]
 *
 * @param {Array<Record<string, any>>} data id 与 pid 构成的扁平数据的数组
 * @param {string} [pidName] pid 的属性名，缺省为 pId
 * @param {string} [childrenName] children 的属性名，缺省为 children
 * @param {string} [idName] id 的属性名，缺省为 id
 * @returns {Array<Record<string, any>>} 树状结构数据
 */
export declare const transformPidToChildren: (data: Record<string, any>[], pidName?: string, childrenName?: string, idName?: string) => Record<string, any>[];
/**
 * 将pid标识的普通数组转换树结构数据
 *
 * @param {Record<string, any> | Record<string, any>[]} data 需要转换的数据
 * @param {string} key id的属性名，默认为'id'
 * @param {string} parentKey 父id的属性名，默认为'pId'
 * @returns {Record<string, any>[]} 树状结构数据
 */
export declare const transformTreeData: (data: Record<string, any> | Record<string, any>[], key?: string, parentKey?: string) => Record<string, any>[];
