/**
 * Copyright (c) 2022 - present TinyVue Authors.
 * Copyright (c) 2022 - present Huawei Cloud Computing Technologies Co., Ltd.
 *
 * Use of this source code is governed by an MIT-style license.
 *
 * THE OPEN SOURCE SOFTWARE IN THIS PRODUCT IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL,
 * BUT WITHOUT ANY WARRANTY, WITHOUT EVEN THE IMPLIED WARRANTY OF MERCHANTABILITY OR FITNESS FOR
 * A PARTICULAR PURPOSE. SEE THE APPLICABLE LICENSES FOR MORE DETAILS.
 *
 */
/**
 * 检查环境是否支持BigInt
 * @returns {boolean} 是否支持BigInt
 */
export declare function supportBigInt(): boolean;
/**
 * 格式化数字字符串
 * @param {string | number} numStr 要格式化的数字或字符串
 * @returns {Object} 格式化后的对象，包含各种数字信息
 */
export declare function trimNumber(numStr: string | number): {
    negative: boolean;
    negativeStr: string;
    trimStr: string;
    integerStr: string;
    decimalStr: string;
    fullStr: string;
};
/**
 * 检查数字是否为科学计数法格式
 * @param {string | number} number 要检查的数字
 * @returns {boolean} 是否为科学计数法格式
 */
export declare function isE(number: string | number): boolean;
/**
 * 验证字符串是否为有效的数字格式
 * @param {string | number | null | undefined} num 要验证的数字或字符串
 * @returns {boolean} 是否为有效的数字格式
 */
export declare function validateNumber(num: string | number | null | undefined): boolean;
/**
 * 获取数字精度（小数位数）
 * [Legacy] 将科学计数法 1e-9 转换为 0.000000001。
 * 注意：如果用户真的需要 1e-9，可能会损失一些精度
 * @param {string | number} number 要检查的数字
 * @returns {number} 小数位数
 */
export declare function getNumberPrecision(number: string | number): number;
/**
 * 将数字（包括科学计数法）转换为 -xxx.yyy 格式
 * @param {string | number} number 要转换的数字
 * @returns {string} 转换后的字符串
 */
export declare function num2str(number: string | number): string;
/**
 * 获取迷你Decimal实例
 * @param {string | number} value 数值
 * @param {any} decimal 可选的decimal库
 * @returns {any} decimal实例
 */
export declare function getMiniDecimal(value: string | number, decimal?: any): any;
/**
 * 大整数小数处理类
 */
export declare class BigIntDecimal {
    /** 是否为空 */
    empty?: boolean;
    /** 原始值 */
    origin: string;
    /** 是否为负数 */
    negative?: boolean;
    /** 整数部分 */
    integer?: bigint | string;
    /** 小数部分 */
    decimal?: bigint;
    /** 小数长度 */
    decimalLen?: number;
    /** 是否为NaN */
    nan?: boolean;
    /**
     * 构造函数
     * @param {string | number} value 数值
     */
    constructor(value: string | number);
    /**
     * 获取小数部分字符串
     * @returns {string} 小数部分字符串
     */
    getDecimalStr(): string;
    /**
     * 获取整数部分字符串
     * @returns {string} 整数部分字符串
     */
    getIntegerStr(): string;
    /**
     * 获取数字符号
     * @returns {string} 负号或空字符串
     */
    getMark(): string;
    /**
     * 对齐小数位，例如：12.3 + 5 = 1230000
     * 这仅用于add函数
     * @param {number} decimalLength 小数长度
     * @returns {bigint} 对齐后的BigInt
     */
    alignDecimal(decimalLength: number): bigint;
    /**
     * 加法操作
     * @param {string | number} value 要添加的值
     * @returns {BigIntDecimal} 计算结果
     */
    add(value: string | number): BigIntDecimal;
    /**
     * 取反操作
     * @returns {BigIntDecimal} 取反后的值
     */
    negate(): BigIntDecimal;
    /**
     * 检查是否为NaN
     * @returns {boolean} 是否为NaN
     */
    isNaN(): boolean;
    /**
     * 检查是否为空
     * @returns {boolean} 是否为空
     */
    isEmpty(): boolean;
    /**
     * 检查是否无效
     * @returns {boolean} 是否无效
     */
    isInvalidate(): boolean;
    /**
     * 小于等于比较
     * @param {BigIntDecimal} target 比较目标
     * @returns {boolean} 是否小于等于
     */
    lessEquals(target: BigIntDecimal): boolean;
    /**
     * 相等比较
     * @param {BigIntDecimal | null | undefined} target 比较目标
     * @returns {boolean} 是否相等
     */
    equals(target: BigIntDecimal | null | undefined): boolean;
    /**
     * 转换为数字
     * @returns {number} 数字值
     */
    toNumber(): number;
    /**
     * 转换为字符串
     * @param {boolean} safe 是否安全转换，默认为true
     * @returns {string} 字符串表示
     */
    toString(safe?: boolean): string;
}
/**
 * 普通数字小数处理类
 */
export declare class NumberDecimal {
    /** 是否为空 */
    empty?: boolean;
    /** 原始值 */
    origin: string;
    /** 数字值 */
    number?: number;
    /**
     * 构造函数
     * @param {string | number} value 数值
     */
    constructor(value?: string | number);
    /**
     * 取反操作
     * @returns {NumberDecimal} 取反后的值
     */
    negate(): NumberDecimal;
    /**
     * 加法操作
     * @param {string | number} value 要添加的值
     * @returns {NumberDecimal} 计算结果
     */
    add(value: string | number): NumberDecimal;
    /**
     * 检查是否为NaN
     * @returns {boolean} 是否为NaN
     */
    isNaN(): boolean;
    /**
     * 检查是否为空
     * @returns {boolean} 是否为空
     */
    isEmpty(): boolean;
    /**
     * 检查是否无效
     * @returns {boolean} 是否无效
     */
    isInvalidate(): boolean;
    /**
     * 相等比较
     * @param {NumberDecimal | null | undefined} target 比较目标
     * @returns {boolean} 是否相等
     */
    equals(target: NumberDecimal | null | undefined): boolean;
    /**
     * 小于等于比较
     * @param {NumberDecimal} target 比较目标
     * @returns {boolean} 是否小于等于
     */
    lessEquals(target: NumberDecimal): boolean;
    /**
     * 转换为数字
     * @returns {number} 数字值
     */
    toNumber(): number;
    /**
     * 转换为字符串
     * @param {boolean} safe 是否安全转换，默认为true
     * @returns {string} 字符串表示
     */
    toString(safe?: boolean): string;
}
/**
 * 设置Decimal类
 * @param {any} decimaljs 自定义decimal库
 */
export declare const setDecimalClass: (decimaljs?: any) => void;
/**
 * 比较两个值是否小于等于关系
 * @param {string | number} value1 第一个值
 * @param {string | number} value2 第二个值
 * @returns {boolean} value1 <= value2
 */
export declare function lessEquals(value1: string | number, value2: string | number): boolean;
/**
 * 比较两个值是否相等
 * @param {string | number} value1 第一个值
 * @param {string | number} value2 第二个值
 * @returns {boolean} value1 === value2
 */
export declare function equalsDecimal(value1: string | number, value2: string | number): boolean;
/**
 * 将数字格式化为固定精度
 * @param {string | number} numStr 数字或数字字符串
 * @param {number} precision 精度（小数位数）
 * @param {number} rounding 舍入方式，默认为5（四舍五入）
 * @returns {string} 格式化后的字符串
 */
export declare function toFixed(numStr: string | number, precision: number, rounding?: number): string;
