import { toFixed as roundFixed } from '../bigInt';
export { roundFixed };
/**
 * Decimal 类的接口定义
 */
interface IDecimal {
    internal: string;
    asInt: {
        value: string | number;
        exp: number;
    };
    add: (target: number | string | IDecimal) => IDecimal;
    sub: (target: number | string | IDecimal) => IDecimal;
    mul: (target: number | string | IDecimal) => IDecimal;
    div: (target: number | string | IDecimal) => IDecimal;
    toString: () => string;
    toNumber: () => number;
}
/**
 * Decimal 类，解决 JS 的计算精度问题。
 *
 *     // 加法运算 1.1 + 2.2 = 3.3000000000000003
 *     Decimal.add(1.1, 2.2).toNumber()           // 3.3
 *     new Decimal('1.1').add('2.2').toString()   // "3.3"
 *
 *     // 减法运算 0.3 - 0.1 = 0.19999999999999998
 *     Decimal.sub(0.3, 0.1).toNumber()           // 0.2
 *     new Decimal('0.3').sub('0.1').toString()   // "0.2"
 *
 *     // 乘法运算 4.01 * 2.01 = 8.060099999999998
 *     Decimal.mul(4.01, 2.01).toNumber()         // 8.0601
 *     new Decimal('4.01').mul('2.01').toString() // "8.0601"
 *
 *     // 除法运算 0.3 / 0.1 = 2.9999999999999996
 *     Decimal.div(0.3, 0.1).toNumber()           // 3
 *     new Decimal('0.3').div('0.1').toString()   // "3"
 *
 * @param {Number|String|IDecimal} num 数字或字符串代表的数字
 * @returns {IDecimal} Decimal实例
 */
export declare function Decimal(this: IDecimal | null | undefined, num: number | string | IDecimal): IDecimal;
/**
 * 使用定点表示法表示给定数字的字符串，解决 JS 的计算精度问题。
 *
 *     toFixed(1.1 + 2.2, 2)   // "3.30"
 *     toFixed(0.3 - 0.1, 2)   // "0.20"
 *     toFixed(4.01 * 2.01, 4) // "8.0601"
 *     toFixed(0.3 / 0.1, 2)   // "3.00"
 *     toFixed(0.0001, 2)      // "0.00"
 *     toFixed(0.0001, 3)      // "0.000"
 *     toFixed(0.0001, 4)      // "0.0001"
 *     toFixed(0.0001, 5)      // "0.00010"
 *     toFixed(-0.0001, 2)     // "0.00"
 *     toFixed(-0.0001, 3)     // "0.000"
 *     toFixed(-0.0001, 4)     // "-0.0001"
 *     toFixed(-0.0001, 5)     // "-0.00010"
 *
 * @param {number} num 需精确计算的数字
 * @param {number} [fraction=0] 浮点数的小数部分，默认0位
 * @returns {string} 格式化后的字符串
 */
export declare const toFixed: (num: number, fraction?: number) => string;
/**
 * 格式化数字的接口
 */
interface FormatNumberOptions {
    fraction?: number;
    rounding?: string;
    prefix?: string;
    decimalSeparator?: string;
    suffix?: string;
    zeroize?: boolean;
    secondaryGroupSize?: number;
    groupSize?: number;
    groupSeparator?: string;
    fractionGroupSize?: number;
    fractionGroupSeparator?: string;
}
/**
 * 格式化数字
 * @param {number|string} value 要格式化的数值
 * @param {FormatNumberOptions} format 格式化选项
 * @returns {string} 格式化后的字符串
 */
export declare const formatNumber: (value: number | string, format?: FormatNumberOptions) => string;
/**
 * 恢复数字
 * @param {number|string} number 要恢复的数字
 * @param {object} format 格式选项
 * @returns {number} 恢复后的数字
 */
export declare const recoverNumber: (number: number | string, format?: FormatNumberOptions) => number;
