/**
 * Copyright (c) 2022 - present TinyVue Authors.
 * Copyright (c) 2022 - present Huawei Cloud Computing Technologies Co., Ltd.
 *
 * Use of this source code is governed by an MIT-style license.
 *
 * THE OPEN SOURCE SOFTWARE IN THIS PRODUCT IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL,
 * BUT WITHOUT ANY WARRANTY, WITHOUT EVEN THE IMPLIED WARRANTY OF MERCHANTABILITY OR FITNESS FOR
 * A PARTICULAR PURPOSE. SEE THE APPLICABLE LICENSES FOR MORE DETAILS.
 *
 */
/**
 * 为元素绑定事件监听器
 * @param el 目标DOM元素
 * @param event 事件名称
 * @param handler 事件处理函数
 * @param options 事件选项，默认为false
 */
export declare const on: (el: EventTarget, event: string, handler: (this: HTMLElement, ev: Event) => any, options?: boolean | AddEventListenerOptions) => void;
/**
 * 移除元素的事件监听器
 * @param el 目标DOM元素
 * @param event 事件名称
 * @param handler 事件处理函数
 * @param options 事件选项，默认为false
 */
export declare const off: (el: EventTarget, event: string, handler: (this: HTMLElement, ev: Event) => any, options?: boolean | EventListenerOptions) => void;
/**
 * 为元素绑定一次性事件，触发后自动移除
 * @param el 目标DOM元素
 * @param event 事件名称
 * @param fn 事件处理函数
 */
export declare const once: (el: HTMLElement, event: string, fn: (this: HTMLElement, ev: Event) => any) => void;
/**
 * 判断元素是否包含指定的类名
 * 只能查询单个类名，且不能有空格
 * @param el 目标DOM元素
 * @param clazz 要检查的类名
 * @returns 如果元素包含该类名则返回true，否则返回false
 */
export declare const hasClass: (el: HTMLElement, clazz: string) => boolean;
/**
 * 为元素添加一个或多个类名
 * clazz允许为用空格分隔的多个类名
 * @param el 目标DOM元素
 * @param clazz 要添加的类名，多个类名用空格分隔
 */
export declare const addClass: (el: HTMLElement, clazz?: string) => void;
/**
 * 从元素移除一个或多个类名
 * clazz允许为用空格分隔的多个类名
 * @param el 目标DOM元素
 * @param clazz 要移除的类名，多个类名用空格分隔
 */
export declare const removeClass: (el: HTMLElement, clazz: string) => void;
/**
 * 获取元素的样式值
 * 优先查找el.style，找不到则调用getComputedStyle(el)
 * @param el 目标DOM元素
 * @param styleName 样式属性名
 * @returns 样式属性值
 */
export declare const getStyle: (el: HTMLElement, styleName: string) => string | null | undefined;
/**
 * 设置元素的样式
 * @param el 目标DOM元素
 * @param name 样式属性名或样式对象。当它是对象时，遍历所有属性；当它是字符串时，需要传入第3个参数value
 * @param value 样式属性值，当name为字符串时使用
 */
export declare const setStyle: (el: HTMLElement, name: string | Record<string, any>, value?: any) => void;
/**
 * 判断元素是否有滚动样式
 * @param el 目标DOM元素
 * @param vertical true时只判断overflow-y属性；false时只判断overflow-x属性；不传入时只判断overflow属性
 * @returns 如果元素有滚动样式则返回匹配结果，否则返回null或undefined
 */
export declare const isScroll: (el: HTMLElement, vertical?: boolean) => RegExpMatchArray | null | undefined;
/**
 * 查找离元素最近的可滚动父元素
 * @param el 目标DOM元素
 * @param vertical true时只判断overflow-y属性；false时只判断overflow-x属性；不传入时只判断overflow属性
 * @returns 最近的可滚动父元素，如果没有则返回元素自身
 */
export declare const getScrollContainer: (el: HTMLElement, vertical?: boolean) => Window | HTMLElement | undefined;
/**
 * 判断元素是否完全在容器内部
 * 四个边有重合都不行，必须完全在里面
 * @param el 目标DOM元素
 * @param container 容器元素
 * @returns 如果元素完全在容器内部则返回true，否则返回false
 */
export declare const isInContainer: (el: HTMLElement, container: HTMLElement) => boolean;
/**
 * 获取页面的位置和尺寸信息
 * @returns 包含滚动位置和可视区域尺寸的对象
 * - scrollTop: document或body的垂直滚动位置
 * - scrollLeft: document或body的水平滚动位置
 * - visibleHeight: 可视区高度（不含滚动条）
 * - visibleWidth: 可视区宽度（不含滚动条）
 */
export declare const getDomNode: () => {
    scrollTop: number;
    scrollLeft: number;
    visibleHeight: number;
    visibleWidth: number;
};
/**
 * 获取元素的垂直滚动位置
 * 处理iOS滚动反弹导致的负scrollTop值
 * @param el 目标DOM元素
 * @returns 元素的垂直滚动位置，最小为0
 */
export declare const getScrollTop: (el: HTMLElement | Window) => number;
/**
 * 阻止事件冒泡
 * @param event 事件对象
 */
export declare const stopPropagation: (event: Event) => void;
/**
 * 阻止事件默认行为
 * @param event 事件对象
 * @param isStopPropagation 是否同时阻止事件冒泡
 */
export declare const preventDefault: (event: Event, isStopPropagation?: boolean) => void;
/**
 * 获取元素的可滚动父元素
 * @param el 目标DOM元素
 * @param root 根元素，默认为window
 * @returns 可滚动的父元素，如果没有则返回root
 */
export declare const getScrollParent: (el: HTMLElement, root?: Window | HTMLElement | undefined) => Window | HTMLElement | null;
interface Hooks {
    onMounted: (callback: () => void) => void;
    ref: <T>() => {
        value?: T;
    };
    watch: <T>(source: {
        value?: T;
    }, callback: () => void) => void;
}
/**
 * 创建一个用于获取元素可滚动父元素的组合式函数
 * @param hooks 包含onMounted、ref和watch的对象
 * @returns 返回一个函数，该函数接收元素引用和根元素，返回可滚动父元素的ref
 */
export declare const useScrollParent: ({ onMounted, ref, watch }: Hooks) => <T extends HTMLElement>(elRef: {
    value?: T | undefined;
}, root?: Window | HTMLElement | undefined) => {
    value?: Window | HTMLElement | null | undefined;
};
/**
 * 判断元素是否处于隐藏状态
 * 递归检查元素及其父元素的display和position属性
 * @param elm 目标DOM元素
 * @returns 如果元素处于隐藏状态则返回true，否则返回false
 */
export declare const isDisplayNone: (elm: HTMLElement | null) => boolean;
export {};
